<?php

namespace App\Filesystem;

use App\Task\TaskInterface;

/**
 * Class to create a new file
 *
 * @author Phil Burton <phil@d3r.com>
 */
class CreateFile implements TaskInterface
{
    /**
     * Name of file to create
     *
     * @var string
     */
    protected $filename;

    /**
     * File contents to write
     *
     * @var string
     */
    protected $contents;

    /**
     * Check if the file already exists
     *
     * @param string $filename
     * @author Phil Burton <phil@d3r.com>
     */
    public function __construct(string $filename, $contents = false)
    {
        $this->filename = $filename;

        if ($contents) {
            $this->contents = $contents;
        }

        if (!is_writable(dirname($filename))) {
            throw new \Exception('Cannot create file at: ' . $filename);
        }

        if (file_exists($filename)) {
            throw new \Exception('File already exists at: ' . $filename);
        }
    }

    /**
     * Create the new file
     *
     * @author Phil Burton <phil@d3r.com>
     */
    public function execute()
    {
        touch($this->filename);

        $contents = $this->contents;
        if ($contents) {
            file_put_contents($this->filename, $contents);
        }
    }
}
